@@ -1,3 +1,20 @@
+# Copyright 2012-2013 Arthur Noel
+#
+# This file is part of Stacked.
+#
+# Stacked is free software: you can redistribute it and/or modify it under the
+# terms of the GNU General Public License as published by the Free Software
+# Foundation, either version 3 of the License, or (at your option) any later
+# version.
+#
+# Stacked is distributed in the hope that it will be useful, but WITHOUT ANY
+# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
+# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# Stacked. If not, see <http://www.gnu.org/licenses/>.
+
+
 class Stacked(object):
 
     def __init__(self):
@@ -24,9 +41,8 @@ class Stacked(object):
                 for key in current:
                     if key not in patch:
                         patch[key] = current[key]
-                patch = patch
-        self._patch_stack.append((target, member, current))
         self._patch_target(target, member, patch)
+        self._patch_stack.append((target, member, current))
 
     def _register_patch(self, target, member, patch):
         self._to_patch.append((target, member, patch))
